@@ -18,15 +18,3 @@ NULL
 # \lifecycle{deprecated}
 # \lifecycle{defunct}
 # \lifecycle{archived}
-
-#' Pipe operator
-#'
-#' See \code{magrittr::\link[magrittr:pipe]{\%>\%}} for details.
-#'
-#' @name %>%
-#' @rdname pipe
-#' @keywords internal
-#' @export
-#' @importFrom dplyr %>%
-#' @usage lhs \%>\% rhs
-NULL
