@@ -2,8 +2,8 @@
 if (getRversion() >= "2.15.1") {
   utils::globalVariables(unique(c(
     "labelp", # cor plot
-    c("..density..", "..scaled..", "x"), # facetdensitystrip plot
-    c("..scaled..", "x"), #density diagonal plot
+    c("x"), # facetdensitystrip plot
+    c("x"), # density diagonal plot
     c("x", "y", "lab"), # internal axis plot
     c("x", "y", "result", "freq"), # fluctuation plot
     c("weight") # ggally_summarise_by
@@ -120,20 +120,20 @@ remove_color_unless_equal <- function(mapping, to = c("x", "y")) {
 #' p_ <- GGally::print_if_interactive
 #'
 #' data(mtcars)
-#' p_(ggally_points(mtcars, mapping = ggplot2::aes(x = disp, y = hp)))
-#' p_(ggally_points(mtcars, mapping = ggplot2::aes_string(x = "disp", y = "hp")))
+#' p_(ggally_points(mtcars, mapping = ggplot2::aes(disp, hp)))
+#' p_(ggally_points(mtcars, mapping = ggplot2::aes(disp, hp)))
 #' p_(ggally_points(
 #'   mtcars,
-#'   mapping = ggplot2::aes_string(
-#'     x     = "disp",
-#'     y     = "hp",
-#'     color = "as.factor(cyl)",
-#'     size  = "gear"
+#'   mapping = ggplot2::aes(
+#'     x     = disp,
+#'     y     = hp,
+#'     color = as.factor(cyl),
+#'     size  = gear
 #'   )
 #' ))
-ggally_points <- function(data, mapping, ...){
-
-  p <- ggplot(data = data, mapping = mapping) + geom_point(...)
+ggally_points <- function(data, mapping, ...) {
+  p <- ggplot(data = data, mapping = mapping) +
+    geom_point(...)
 
   p
 }
@@ -157,17 +157,15 @@ ggally_points <- function(data, mapping, ...){
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_smooth(tips, mapping = ggplot2::aes(x = total_bill, y = tip)))
-#' p_(ggally_smooth(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "tip")))
-#' p_(ggally_smooth(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "tip", color = "sex")))
+#' p_(ggally_smooth(tips, mapping = ggplot2::aes(total_bill, tip, color = sex)))
 ggally_smooth <- function(data, mapping, ..., method = "lm", formula = y ~ x, se = TRUE, shrink = TRUE) {
-
   p <- ggplot(data = data, mapping)
 
   p <- p + geom_point(...)
 
-  if (! is.null(mapping$color) || ! is.null(mapping$colour)) {
+  if (!is.null(mapping$color) || !is.null(mapping$colour)) {
     p <- p + geom_smooth(method = method, se = se, formula = formula)
   } else {
     p <- p + geom_smooth(method = method, se = se, formula = formula, colour = I("black"))
@@ -210,25 +208,24 @@ ggally_smooth_lm <- function(data, mapping, ...) {
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_density(tips, mapping = ggplot2::aes(x = total_bill, y = tip)))
-#' p_(ggally_density(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "tip")))
 #' p_(ggally_density(
 #'   tips,
-#'   mapping = ggplot2::aes_string(x = "total_bill", y = "tip", fill = "..level..")
+#'   mapping = ggplot2::aes(total_bill, tip, fill = after_stat(level))
 #' ))
 #' p_(ggally_density(
 #'   tips,
-#'   mapping = ggplot2::aes_string(x = "total_bill", y = "tip", fill = "..level..")
+#'   mapping = ggplot2::aes(total_bill, tip, fill = after_stat(level))
 #' ) + ggplot2::scale_fill_gradient(breaks = c(0.05, 0.1, 0.15, 0.2)))
-ggally_density <- function(data, mapping, ...){
+ggally_density <- function(data, mapping, ...) {
   rangeX <- range(eval_data_col(data, mapping$x), na.rm = TRUE)
   rangeY <- range(eval_data_col(data, mapping$y), na.rm = TRUE)
 
   p <- ggplot(data = data) +
     geom_point(
       data = data.frame(rangeX = rangeX, rangeY = rangeY),
-      mapping = aes(x = rangeX, y = rangeY),
+      mapping = aes(x = !!as.name("rangeX"), y = !!as.name("rangeY")),
       alpha = 0
     )
 
@@ -275,12 +272,12 @@ ggally_density <- function(data, mapping, ...){
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
-#' p_(ggally_cor(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "tip")))
+#' data(tips)
+#' p_(ggally_cor(tips, mapping = ggplot2::aes(total_bill, tip)))
 #' # display with grid
 #' p_(ggally_cor(
 #'   tips,
-#'   mapping = ggplot2::aes_string(x = "total_bill", y = "tip"),
+#'   mapping = ggplot2::aes(total_bill, tip),
 #'   display_grid = TRUE
 #' ))
 #' # change text attributes
@@ -294,26 +291,25 @@ ggally_density <- function(data, mapping, ...){
 #' # split by a variable
 #' p_(ggally_cor(
 #'   tips,
-#'   mapping = ggplot2::aes_string(x = "total_bill", y = "tip", color = "sex"),
+#'   mapping = ggplot2::aes(total_bill, tip, color = sex),
 #'   size = 5
 #' ))
 ggally_cor <- function(
-  data,
-  mapping,
-  ...,
-  stars = TRUE,
-  method = "pearson",
-  use = "complete.obs",
-  display_grid = FALSE,
-  digits = 3,
-  title_args = list(...),
-  group_args = list(...),
-  justify_labels = "right",
-  align_percent = 0.5,
-  title = "Corr",
-  alignPercent = warning("deprecated. Use `align_percent`"),
-  displayGrid = warning("deprecated. Use `display_grid`")
-) {
+    data,
+    mapping,
+    ...,
+    stars = TRUE,
+    method = "pearson",
+    use = "complete.obs",
+    display_grid = FALSE,
+    digits = 3,
+    title_args = list(...),
+    group_args = list(...),
+    justify_labels = "right",
+    align_percent = 0.5,
+    title = "Corr",
+    alignPercent = warning("deprecated. Use `align_percent`"),
+    displayGrid = warning("deprecated. Use `display_grid`")) {
   if (!missing(alignPercent)) {
     warning("`alignPercent` is deprecated. Please use `align_percent` if alignment still needs to be adjusted")
     align_percent <- alignPercent
@@ -390,32 +386,31 @@ ggally_cor <- function(
 #' @seealso \code{\link{ggally_cor}}
 #' @export
 ggally_statistic <- function(
-  data,
-  mapping,
-  text_fn,
-  title,
-  na.rm = NA,
-  display_grid = FALSE,
-  justify_labels = "right",
-  justify_text = "left",
-  sep = ": ",
-  family = "mono",
-  title_args = list(),
-  group_args = list(),
-  align_percent = 0.5,
-  title_hjust = 0.5,
-  group_hjust = 0.5
-) {
+    data,
+    mapping,
+    text_fn,
+    title,
+    na.rm = NA,
+    display_grid = FALSE,
+    justify_labels = "right",
+    justify_text = "left",
+    sep = ": ",
+    family = "mono",
+    title_args = list(),
+    group_args = list(),
+    align_percent = 0.5,
+    title_hjust = 0.5,
+    group_hjust = 0.5) {
   set_if_not_there <- function(obj, key, value) {
     obj <- as.list(obj)
-    #if (! "family" %in% rlang::names2(obj)) {
+    # if (! "family" %in% rlang::names2(obj)) {
     #  obj$family <- family
-    #}
+    # }
     obj
   }
 
-  #title_args <- set_if_not_there(title_args, "family", family)
-  #group_args <- set_if_not_there(group_args, "family", family)
+  # title_args <- set_if_not_there(title_args, "family", family)
+  # group_args <- set_if_not_there(group_args, "family", family)
 
   title_args <- set_if_not_there(title_args, "hjust", title_hjust)
   group_args <- set_if_not_there(group_args, "hjust", group_hjust)
@@ -481,11 +476,7 @@ ggally_statistic <- function(
   yrange <- c(ymin - 0.01 * (ymax - ymin), ymax + 0.01 * (ymax - ymin))
 
   # if there is a color grouping...
-  if (
-    !is.null(colorData) &&
-    !inherits(colorData, "AsIs")
-  ) {
-
+  if (!is.null(colorData) && !inherits(colorData, "AsIs")) {
     cord <- ddply(
       data.frame(x = xData, y = yData, color = colorData),
       "color",
@@ -495,12 +486,11 @@ ggally_statistic <- function(
     )
     colnames(cord)[2] <- "text"
 
-
     # put in correct order
     lev <- levels(as.factor(colorData))
     ord <- rep(-1, nrow(cord))
     for (i in 1:nrow(cord)) {
-      for (j in seq_along(lev)){
+      for (j in seq_along(lev)) {
         if (identical(as.character(cord$color[i]), as.character(lev[j]))) {
           ord[i] <- j
         }
@@ -508,7 +498,7 @@ ggally_statistic <- function(
     }
     cord <- cord[order(ord[ord >= 0]), ]
 
-        # make labels align together
+    # make labels align together
     cord$label <- str_c(
       format(cord$color, justify = justify_labels),
       sep,
@@ -530,10 +520,7 @@ ggally_statistic <- function(
     p <- do.call(ggally_text, ggally_text_args)
 
     xPos <- rep(align_percent, nrow(cord)) * diff(xrange) + min(xrange, na.rm = TRUE)
-    yPos <- seq(
-      from = 0.9,
-      to = 0.2,
-      length.out = nrow(cord) + 1)
+    yPos <- seq(from = 0.9, to = 0.2, length.out = nrow(cord) + 1)
     yPos <- yPos * diff(yrange) + min(yrange, na.rm = TRUE)
     yPos <- yPos[-1]
 
@@ -545,17 +532,16 @@ ggally_statistic <- function(
       list(
         data = cordf,
         aes(
-          x = xPos,
-          y = yPos,
-          label = labelp,
-          color = labelp
+          x = !!as.name("xPos"),
+          y = !!as.name("yPos"),
+          label = !!as.name("labelp"),
+          color = !!as.name("labelp")
         )
       ),
       group_args
     )
     p <- p + do.call(geom_text, geom_text_args)
   } else {
-
     ggally_text_args <- append(
       list(
         label = paste0(title, sep, text_fn(xVal, yVal), collapse = ""),
@@ -585,7 +571,6 @@ ggally_statistic <- function(
   }
 
   p + theme(legend.position = "none")
-
 }
 
 
@@ -607,17 +592,16 @@ ggally_statistic <- function(
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_box(tips, mapping = ggplot2::aes(x = total_bill, y = sex)))
-#' p_(ggally_box(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "sex")))
 #' p_(ggally_box(
 #'   tips,
-#'   mapping        = ggplot2::aes_string(y = "total_bill", x = "sex", color = "sex"),
+#'   mapping        = ggplot2::aes(sex, total_bill, color = sex),
 #'   outlier.colour = "red",
 #'   outlier.shape  = 13,
 #'   outlier.size   = 8
 #' ))
-ggally_box <- function(data, mapping, ...){
+ggally_box <- function(data, mapping, ...) {
   mapping <- mapping_color_to_fill(mapping)
 
   ggally_dot_and_box(data, mapping, ..., boxPlot = TRUE)
@@ -645,18 +629,17 @@ ggally_box_no_facet <- function(data, mapping, ...) {
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_dot(tips, mapping = ggplot2::aes(x = total_bill, y = sex)))
-#' p_(ggally_dot(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "sex")))
 #' p_(ggally_dot(
 #'   tips,
-#'   mapping = ggplot2::aes_string(y = "total_bill", x = "sex", color = "sex")
+#'   mapping = ggplot2::aes(sex, total_bill, color = sex)
 #' ))
 #' p_(ggally_dot(
 #'   tips,
-#'   mapping = ggplot2::aes_string(y = "total_bill", x = "sex", color = "sex", shape = "sex")
-#' ) + ggplot2::scale_shape(solid=FALSE))
-ggally_dot <- function(data, mapping, ...){
+#'   mapping = ggplot2::aes(sex, total_bill, color = sex, shape = sex)
+#' ) + ggplot2::scale_shape(solid = FALSE))
+ggally_dot <- function(data, mapping, ...) {
   ggally_dot_and_box(data, mapping, ..., boxPlot = FALSE)
 }
 #' @export
@@ -681,7 +664,7 @@ ggally_dot_no_facet <- function(data, mapping, ...) {
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_dot_and_box(
 #'   tips,
 #'   mapping = ggplot2::aes(x = total_bill, y = sex, color = sex),
@@ -692,8 +675,7 @@ ggally_dot_no_facet <- function(data, mapping, ...) {
 #'   mapping = ggplot2::aes(x = total_bill, y = sex, color = sex),
 #'   boxPlot = FALSE
 #' ))
-ggally_dot_and_box <- function(data, mapping, ..., boxPlot = TRUE){
-
+ggally_dot_and_box <- function(data, mapping, ..., boxPlot = TRUE) {
   horizontal <- is_horizontal(data, mapping)
 
   if (horizontal) {
@@ -714,7 +696,6 @@ ggally_dot_and_box <- function(data, mapping, ..., boxPlot = TRUE){
     p <- p +
       facet_grid(paste(". ~ ", xVal, sep = ""), scales = "free_x") +
       theme(panel.spacing = unit(0.1, "lines"))
-
   } else {
     p <- p +
       coord_flip() +
@@ -726,7 +707,6 @@ ggally_dot_and_box <- function(data, mapping, ..., boxPlot = TRUE){
 }
 
 ggally_dot_and_box_no_facet <- function(data, mapping, ..., boxPlot = TRUE) {
-
   horizontal <- is_horizontal(data, mapping)
 
   if (horizontal) {
@@ -744,7 +724,7 @@ ggally_dot_and_box_no_facet <- function(data, mapping, ..., boxPlot = TRUE) {
   if (horizontal) {
     p <- p +
       scale_x_discrete(
-        limits = rev(levels(eval_data_col(data, mapping$x)))
+        limits = rev(levels(as.factor(eval_data_col(data, mapping$x))))
       ) +
       coord_flip()
   }
@@ -768,11 +748,10 @@ ggally_dot_and_box_no_facet <- function(data, mapping, ..., boxPlot = TRUE) {
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_facethist(tips, mapping = ggplot2::aes(x = tip, y = sex)))
-#' p_(ggally_facethist(tips, mapping = ggplot2::aes_string(x = "tip", y = "sex"), binwidth = 0.1))
-ggally_facethist <- function(data, mapping, ...){
-
+#' p_(ggally_facethist(tips, mapping = ggplot2::aes(x = tip, y = sex), binwidth = 0.1))
+ggally_facethist <- function(data, mapping, ...) {
   mapping <- mapping_color_to_fill(mapping)
 
   horizontal <- is_horizontal(data, mapping)
@@ -818,13 +797,13 @@ ggally_facethist <- function(data, mapping, ...){
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_facetdensity(tips, mapping = ggplot2::aes(x = total_bill, y = sex)))
 #' p_(ggally_facetdensity(
 #'   tips,
-#'   mapping = ggplot2::aes_string(y = "total_bill", x = "sex", color = "sex")
+#'   mapping = ggplot2::aes(sex, total_bill, color = sex)
 #' ))
-ggally_facetdensity <- function(data, mapping, ...){
+ggally_facetdensity <- function(data, mapping, ...) {
   ggally_facetdensitystrip(data, mapping, ..., den_strip = FALSE)
 }
 
@@ -842,14 +821,13 @@ ggally_facetdensity <- function(data, mapping, ...){
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_denstrip(tips, mapping = ggplot2::aes(x = total_bill, y = sex)))
-#' p_(ggally_denstrip(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "sex")))
 #' p_(ggally_denstrip(
 #'   tips,
-#'   mapping = ggplot2::aes_string(x = "sex", y = "tip", binwidth = "0.2")
+#'   mapping = ggplot2::aes(sex, tip), binwidth = 0.2
 #' ) + ggplot2::scale_fill_gradient(low = "grey80", high = "black"))
-ggally_denstrip <- function(data, mapping, ...){
+ggally_denstrip <- function(data, mapping, ...) {
   mapping <- mapping_color_to_fill(mapping)
 
   ggally_facetdensitystrip(data, mapping, ..., den_strip = TRUE)
@@ -869,7 +847,7 @@ ggally_denstrip <- function(data, mapping, ...){
 #' @examples
 #' example(ggally_facetdensity)
 #' example(ggally_denstrip)
-ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE){
+ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE) {
   horizontal <- is_horizontal(data, mapping)
 
   if (!horizontal) {
@@ -881,13 +859,13 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE){
   mappingY <- mapping$y # nolint
   mapping$y <- NULL # will be faceted
 
-  p <- ggplot(data = data, mapping) + labs(x = xVal, y = yVal)
+  p <- ggplot(data = data, mapping) +
+    labs(x = xVal, y = yVal)
 
   if (identical(den_strip, TRUE)) {
-
     p <- p +
       geom_histogram(
-        mapping = aes(fill = ..density..), # nolint
+        mapping = aes(fill = after_stat(!!as.name("density"))), # nolint
         position = "fill",
         ...
       ) +
@@ -895,12 +873,11 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE){
         breaks = c(0.5),
         labels = "1"
       )
-
   } else {
     p <- p +
       stat_density(
-      aes(
-          y = ..scaled.. * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
+        aes(
+          y = after_stat(!!as.name("scaled")) * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
         ),
         position = "identity",
         geom = "line",
@@ -943,11 +920,10 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE){
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_densityDiag(tips, mapping = ggplot2::aes(x = total_bill)))
 #' p_(ggally_densityDiag(tips, mapping = ggplot2::aes(x = total_bill, color = day)))
-ggally_densityDiag <- function(data, mapping, ..., rescale = FALSE){
-
+ggally_densityDiag <- function(data, mapping, ..., rescale = FALSE) {
   mapping <- mapping_color_to_fill(mapping)
 
   p <- ggplot(data, mapping) +
@@ -957,7 +933,7 @@ ggally_densityDiag <- function(data, mapping, ..., rescale = FALSE){
     p <- p +
       stat_density(
         aes(
-          y = ..scaled.. * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
+          y = after_stat(!!as.name("scaled")) * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
         ),
         position = "identity",
         geom = "line",
@@ -985,11 +961,10 @@ ggally_densityDiag <- function(data, mapping, ..., rescale = FALSE){
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_barDiag(tips, mapping = ggplot2::aes(x = day)))
 #' p_(ggally_barDiag(tips, mapping = ggplot2::aes(x = tip), binwidth = 0.25))
-ggally_barDiag <- function(data, mapping, ..., rescale = FALSE){
-
+ggally_barDiag <- function(data, mapping, ..., rescale = FALSE) {
   mapping <- mapping_color_to_fill(mapping)
 
   mapping$y <- NULL
@@ -1000,27 +975,22 @@ ggally_barDiag <- function(data, mapping, ..., rescale = FALSE){
 
   if (is_date(x_data)) {
     p <- p + geom_histogram(...)
-    #TODO make y axis lines match date positions
+    # TODO make y axis lines match date positions
     # buildInfo <- ggplot_build(p + geom_bar(...))
     # histBarPerc <- buildInfo$data[[1]]$ncount
-
   } else if (numer) {
     if (identical(rescale, TRUE)) {
       p <- p + geom_histogram(
         aes(
-          y = ..density.. / max(..density..) * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
+          y = after_stat(!!as.name("density")) / max(after_stat(!!as.name("density"))) * diff(range(x, na.rm = TRUE)) + min(x, na.rm = TRUE) # nolint
         ),
         ...
       ) + coord_cartesian(ylim = range(eval_data_col(data, mapping$x), na.rm = TRUE))
-
     } else {
       p <- p + geom_histogram(...)
-
     }
-
-   } else {
+  } else {
     p <- p + geom_bar(...)
-
   }
 
   p
@@ -1048,15 +1018,13 @@ ggally_barDiag <- function(data, mapping, ..., rescale = FALSE){
 #' p_(ggally_text("Example 1"))
 #' p_(ggally_text("Example\nTwo", mapping = ggplot2::aes(size = 15), color = I("red")))
 ggally_text <- function(
-  label,
-  mapping = ggplot2::aes(color = "black"),
-  xP = 0.5,
-  yP = 0.5,
-  xrange = c(0, 1),
-  yrange = c(0, 1),
-  ...
-){
-
+    label,
+    mapping = ggplot2::aes(color = I("black")),
+    xP = 0.5,
+    yP = 0.5,
+    xrange = c(0, 1),
+    yrange = c(0, 1),
+    ...) {
   theme <- theme_get()
 
   p <- ggplot() +
@@ -1073,9 +1041,9 @@ ggally_text <- function(
     ) +
     labs(x = NULL, y = NULL)
 
-  new_mapping <- aes_string(
-    x = xP * diff(xrange) + min(xrange, na.rm = TRUE),
-    y = yP * diff(yrange) + min(yrange, na.rm = TRUE)
+  new_mapping <- aes(
+    x = !!xP * diff(xrange) + min(xrange, na.rm = TRUE),
+    y = !!yP * diff(yrange) + min(yrange, na.rm = TRUE)
   )
   if (is.null(mapping)) {
     mapping <- new_mapping
@@ -1086,23 +1054,22 @@ ggally_text <- function(
   # dont mess with color if it's already there
   if (!is.null(mapping$colour)) {
     p <- p +
-       geom_text( label = label, mapping = mapping, ...) +
-       guides(colour = "none")
+      geom_text(label = label, mapping = mapping, ...) +
+      guides(colour = "none")
   } else if ("colour" %in% names(aes(...))) {
     p <- p +
-       geom_text( label = label, mapping = mapping, ...)
+      geom_text(label = label, mapping = mapping, ...)
   } else {
     bg <- ifnull(theme$panel.background$fill, "grey92")
     fg <- ifnull(theme$axis.text$colour, "gray30")
     colour <- scales::colour_ramp(c(bg, fg))(0.75)
     p <- p +
-       geom_text( label = label, mapping = mapping, colour = colour, ...)
+      geom_text(label = label, mapping = mapping, colour = colour, ...)
   }
 
   p <- p + theme(legend.position = "none")
 
   p
-
 }
 
 
@@ -1122,26 +1089,19 @@ get_x_axis_labels <- function(p, xRange) {
   # have to do a function as filter doesn't work
   get_raw_grob_by_name <- function(g, name) {
     for (item in g$grobs) {
-      if (str_detect(item$name, name) ) {
+      if (str_detect(item$name, name)) {
         return(item$children[[1]])
       }
     }
     NULL
   }
-  name <-
-    if (packageVersion("ggplot2") >= 3.3) {
-      "title"
-    } else {
-      "axis.text.x"
-    }
-
-  xAxisGrob <- get_raw_grob_by_name(axisTable, name)
+  xAxisGrob <- get_raw_grob_by_name(axisTable, "title")
 
   axisBreaks <- as.numeric(xAxisGrob$label)
 
   axisLabs <- rbind(
     expand.grid(xPos = axisBreaks[1], yPos = axisBreaks),
-    expand.grid(xPos = axisBreaks,    yPos = axisBreaks[1])
+    expand.grid(xPos = axisBreaks, yPos = axisBreaks[1])
   )[-1, ]
 
   axisLabs <- as.data.frame(axisLabs)
@@ -1196,28 +1156,27 @@ get_x_axis_labels <- function(p, xRange) {
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
-#' p_(ggally_diagAxis(tips, ggplot2::aes(x=tip)))
-#' p_(ggally_diagAxis(tips, ggplot2::aes(x=sex)))
+#' data(tips)
+#' p_(ggally_diagAxis(tips, ggplot2::aes(x = tip)))
+#' p_(ggally_diagAxis(tips, ggplot2::aes(x = sex)))
 ggally_diagAxis <- function(
-  data,
-  mapping,
-  label = mapping$x,
-  labelSize     = 5,
-  labelXPercent = 0.5,
-  labelYPercent = 0.55,
-  labelHJust    = 0.5,
-  labelVJust    = 0.5,
-  gridLabelSize = 4,
-  ...
-) {
+    data,
+    mapping,
+    label = mapping$x,
+    labelSize = 5,
+    labelXPercent = 0.5,
+    labelYPercent = 0.55,
+    labelHJust = 0.5,
+    labelVJust = 0.5,
+    gridLabelSize = 4,
+    ...) {
   if (is.null(mapping$x)) {
     stop("mapping$x is null.  There must be a column value in this location.")
   }
   mapping$y <- NULL
-  numer <- ! is_horizontal(data, mapping, "x")
+  numer <- !is_horizontal(data, mapping, "x")
 
-  if (! is.character(label)) {
+  if (!is.character(label)) {
     label <- mapping_string(mapping$x)
   }
 
@@ -1233,7 +1192,7 @@ ggally_diagAxis <- function(
 
     p <- ggally_text(
       label   = label,
-      mapping = aes(col = "grey50"),
+      mapping = aes(col = I("grey50")),
       xrange  = xrange,
       yrange  = xrange,
       size    = labelSize,
@@ -1246,25 +1205,24 @@ ggally_diagAxis <- function(
     axisBreaks <- get_x_axis_labels(p, xrange)
     # print(axisBreaks)
     p <- p + geom_text(
-      data    = axisBreaks,
-      mapping = aes_string(
-        x     = "xPos",
-        y     = "yPos",
-        label = "lab",
-        hjust = "hjust",
-        vjust = "vjust"
+      data = axisBreaks,
+      mapping = aes(
+        x     = !!as.name("xPos"),
+        y     = !!as.name("yPos"),
+        label = !!as.name("lab"),
+        hjust = !!as.name("hjust"),
+        vjust = !!as.name("vjust")
       ),
-      col     = "grey50",
+      col = "grey50",
       size = gridLabelSize
     )
-
   } else {
     breakLabels <- levels(as.factor(xData))
     numLvls <- length(breakLabels)
 
     p <- ggally_text(
       label   = label,
-      mapping = aes(col = "grey50"),
+      mapping = aes(col = I("grey50")),
       xrange  = c(0, 1),
       yrange  = c(0, 1),
       size    = labelSize,
@@ -1273,7 +1231,7 @@ ggally_diagAxis <- function(
       hjust   = labelHJust,
       vjust   = labelVJust
     )
-    #axisBreaks <- (1+2*0:(numLvls-1))/(2*numLvls)
+    # axisBreaks <- (1+2*0:(numLvls-1))/(2*numLvls)
     axisBreaks <- 0:(numLvls - 1) * (0.125 + (1 - 0.125 * (numLvls - 1)) / numLvls) +
       (1 - 0.125 * (numLvls - 1)) / (2 * numLvls)
 
@@ -1286,9 +1244,9 @@ ggally_diagAxis <- function(
     p <- p + geom_text(
       data = axisLabs,
       mapping = aes(
-        x     = x,
-        y     = y,
-        label = lab
+        x     = !!as.name("x"),
+        y     = !!as.name("y"),
+        label = !!as.name("lab")
       ),
       col = "grey50",
       size = gridLabelSize
@@ -1298,12 +1256,11 @@ ggally_diagAxis <- function(
     p$scales$scales[[1]]$breaks <- axisBreaks
     p$scales$scales[[2]]$breaks <- axisBreaks
     # pLabs <- pLabs +
-    #   scale_x_continuous(breaks=axisBreaks,limits=c(0,1)) +
-    #   scale_y_continuous(breaks=axisBreaks,limits=c(0,1))
+    #   scale_x_continuous(breaks = axisBreaks, limits = c(0, 1)) +
+    #   scale_y_continuous(breaks = axisBreaks, limits = c(0, 1))
   }
 
   p
-
 }
 
 #' Faceted bar plot
@@ -1320,14 +1277,13 @@ ggally_diagAxis <- function(
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_facetbar(tips, ggplot2::aes(x = sex, y = smoker, fill = time)))
 #' p_(ggally_facetbar(tips, ggplot2::aes(x = smoker, y = sex, fill = time)))
-ggally_facetbar <- function(data, mapping, ...){
-
+ggally_facetbar <- function(data, mapping, ...) {
   mapping <- mapping_color_to_fill(mapping)
 
-  # numer <- is.null(attributes(data[,as.character(mapping$x)])$class)
+  # numer <- is.null(attributes(data[, as.character(mapping$x)])$class)
   # xVal <- mapping$x
   yVal <- mapping_string(mapping$y)
   mapping$y <- NULL
@@ -1355,22 +1311,20 @@ ggally_facetbar <- function(data, mapping, ...){
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_ratio(tips, ggplot2::aes(sex, day)))
 #' p_(ggally_ratio(tips, ggplot2::aes(sex, day)) + ggplot2::coord_equal())
 #' # only plot tiles greater or equal to 20 and scale to a max of 50
 #' p_(ggally_ratio(
 #'   tips, ggplot2::aes(sex, day),
 #'   floor = 20, ceiling = 50
-#' ) + ggplot2::theme(aspect.ratio = 4/2))
+#' ) + ggplot2::theme(aspect.ratio = 4 / 2))
 ggally_ratio <- function(
-  data,
-  mapping = do.call(ggplot2::aes_string, as.list(colnames(data)[1:2])),
-  ...,
-  floor = 0,
-  ceiling = NULL
-) {
-
+    data,
+    mapping = ggplot2::aes(!!!stats::setNames(lapply(colnames(data)[1:2], as.name), c("x", "y"))),
+    ...,
+    floor = 0,
+    ceiling = NULL) {
   # capture the original names
   xName <- mapping_string(mapping$x)
   yName <- mapping_string(mapping$y)
@@ -1395,14 +1349,15 @@ ggally_ratio <- function(
   countData[["xPos"]] <- as.numeric(countData[["x"]]) + (1 / 2) * countData[["freqSize"]]
   countData[["yPos"]] <- as.numeric(countData[["y"]]) + (1 / 2) * countData[["freqSize"]]
 
-  p <- ggplot(
+  p <-
+    ggplot(
       data = countData,
-      mapping = aes_string(
-        x = "xPos",
-        y = "yPos",
-        height = "freqSize",
-        width = "freqSize",
-        fill = "col"
+      mapping = aes(
+        x = !!as.name("xPos"),
+        y = !!as.name("yPos"),
+        height = !!as.name("freqSize"),
+        width = !!as.name("freqSize"),
+        fill = !!as.name("col")
       )
     ) +
     geom_tile(...) +
@@ -1457,7 +1412,7 @@ ggally_ratio <- function(
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_count(tips, mapping = ggplot2::aes(x = smoker, y = sex)))
 #' p_(ggally_count(tips, mapping = ggplot2::aes(x = smoker, y = sex, fill = day)))
 #'
@@ -1478,20 +1433,28 @@ ggally_count <- function(data, mapping, ...) {
   # and always be a factor
   count_col <- ".ggally_y"
   data[[count_col]] <- as.factor(eval_data_col(data, mapping$y))
+
+  # Reverse the y axis here. I'd like to perform this in the
+  # `scale_y_continuous(trans="reverse")`, but the trans is applied after
+  # `breaks/labels`
+  data[[count_col]] <- factor(data[[count_col]], levels = rev(levels(data[[count_col]])))
+
   ylabel <- mapping_string(mapping$y)
-  mapping$base_y <- aes_string(base_y = count_col)$base_y
+  mapping$base_y <- aes(base_y = !!as.name(count_col))$base_y
   mapping$y <- NULL
 
   # default values
   args <- list(...)
-  if (!"fill" %in% names(args) & is.null(mapping$fill)) {
-    args$fill <- GeomRect$default_aes$fill
+  if (!"fill" %in% names(args)) {
+    if (is.null(mapping$fill)) {
+      args$fill <- GeomRect$default_aes$fill
+    }
   }
 
   ggplot(data, mapping) +
     do.call(stat_ggally_count, args) +
     scale_y_continuous(
-      breaks = 1:length(levels(data[[count_col]])),
+      breaks = seq_along(levels(data[[count_col]])),
       labels = levels(data[[count_col]])
     ) +
     theme(panel.grid.minor = element_blank()) +
@@ -1505,14 +1468,15 @@ ggally_count <- function(data, mapping, ...) {
 #' @export
 # na.rm = TRUE to remove warnings if NA (cf. stat_count)
 # x.width to control size of tiles
-stat_ggally_count <- function(mapping = NULL, data = NULL,
-                      geom = "tile", position = "identity",
-                      ...,
-                      x.width = .9,
-                      na.rm = FALSE,
-                      show.legend = NA,
-                      inherit.aes = TRUE) {
-
+stat_ggally_count <- function(
+    mapping = NULL,
+    data = NULL,
+    geom = "tile", position = "identity",
+    ...,
+    x.width = .9,
+    na.rm = FALSE,
+    show.legend = NA,
+    inherit.aes = TRUE) {
   params <- list(
     x.width = x.width,
     na.rm = na.rm,
@@ -1547,19 +1511,18 @@ StatGGallyCount <- ggproto("StatGGallyCount", Stat,
     height = after_stat(height),
     y = after_stat(y)
   ),
-
   setup_params = function(data, params) {
     params
   },
-
   extra_params = c("na.rm"),
-
   compute_panel = function(self, data, scales, x.width = NULL) {
-    if (is.null(data$weight))
+    if (is.null(data$weight)) {
       data$weight <- rep(1, nrow(data))
+    }
 
-    if(is.null(x.width))
+    if (is.null(x.width)) {
       x.width <- .9
+    }
 
     # sum weights for each combination of aesthetics
     # the use of . allows to consider all aesthetics defined in data
@@ -1567,8 +1530,15 @@ StatGGallyCount <- ggproto("StatGGallyCount", Stat,
 
     names(panel)[which(names(panel) == "weight")] <- "n"
 
+    # Reverse both the y and fill values here.
+    # This makes the colors appear the correct order
+    # If it is a single color, it won't make any difference in the cum_height
+    panel <- panel[rev(seq_len(nrow(panel))), ]
+
     # compute proportions by x and y
-    f <- function(n) {sum(abs(n), na.rm = TRUE)}
+    f <- function(n) {
+      sum(abs(n), na.rm = TRUE)
+    }
     panel$n_xy <- stats::ave(panel$n, panel$x, panel$base_y, FUN = f)
     panel$prop <- panel$n / panel$n_xy
     panel$width <- sqrt(panel$n_xy) / max(sqrt(panel$n_xy)) * x.width
@@ -1606,12 +1576,12 @@ ggally_countDiag <- function(data, mapping, ...) {
 #' @seealso [ggplot2::element_blank()]
 #' @export
 #' @keywords hplot
-ggally_blank <- function(...){
+ggally_blank <- function(...) {
   aes(...) # ignored
   a <- data.frame(X = 1:2, Y = 1:2)
 
-  p <- ggplot(data = a, aes_string(x = "X", y = "Y")) +
-    geom_point( colour = "transparent") +
+  p <- ggplot(data = a, aes(x = !!as.name("X"), y = !!as.name("Y"))) +
+    geom_point(colour = "transparent") +
     theme(
       axis.line         = element_blank(),
       axis.text.x       = element_blank(),
@@ -1661,7 +1631,7 @@ ggally_blankDiag <- function(...) {
 ggally_na <- function(data = NULL, mapping = NULL, size = 10, color = "grey20", ...) {
   a <- data.frame(x = 1, y = 1, label = "NA")
 
-  p <- ggplot(data = a, aes_string(x = "x", y = "y", label = "label")) +
+  p <- ggplot(data = a, aes(x = !!as.name("X"), y = !!as.name("Y"), label = !!as.name("label"))) +
     geom_text(color = color, size = size, ...) +
     theme(
       axis.line         = element_blank(),
@@ -1711,7 +1681,7 @@ ggally_naDiag <- function(...) {
 #' # Small function to display plots only if it's interactive
 #' p_ <- GGally::print_if_interactive
 #'
-#' data(tips, package = "reshape")
+#' data(tips)
 #' p_(ggally_autopoint(tips, mapping = aes(x = tip, y = total_bill)))
 #' p_(ggally_autopoint(tips, mapping = aes(x = tip, y = sex)))
 #' p_(ggally_autopoint(tips, mapping = aes(x = smoker, y = sex)))
@@ -1729,8 +1699,9 @@ ggally_autopoint <- function(data, mapping, ...) {
   require_namespaces("ggforce")
 
   args <- list(...)
-  if (!"alpha" %in% names(args) & is.null(mapping$alpha))
+  if (!"alpha" %in% names(args) && is.null(mapping$alpha)) {
     args$alpha <- .5
+  }
   # mapping needs to be sent directly to geom_autopoint
   args$mapping <- mapping
 
@@ -1763,7 +1734,7 @@ ggally_autopointDiag <- function(data, mapping, ...) {
 #' p_ <- GGally::print_if_interactive
 #'
 #' if (require(Hmisc)) {
-#'   data(tips, package = "reshape")
+#'   data(tips)
 #'   p_(ggally_summarise_by(tips, mapping = aes(x = total_bill, y = day)))
 #'   p_(ggally_summarise_by(tips, mapping = aes(x = day, y = total_bill)))
 #'
@@ -1786,17 +1757,16 @@ ggally_autopointDiag <- function(data, mapping, ...) {
 #'   p_(ggally_summarise_by(tips, mapping = aes(x = total_bill, y = day), text_fn = weighted_sum))
 #' }
 ggally_summarise_by <- function(
-  data,
-  mapping,
-  text_fn = weighted_median_iqr,
-  text_fn_vertical = NULL,
-  ...)
-{
+    data,
+    mapping,
+    text_fn = weighted_median_iqr,
+    text_fn_vertical = NULL,
+    ...) {
   if (is.null(mapping$x)) stop("'x' aesthetic is required.")
   if (is.null(mapping$y)) stop("'y' aesthetic is required.")
 
   horizontal <- is_horizontal(data, mapping)
-  if(horizontal) {
+  if (horizontal) {
     res <- ddply(
       data.frame(
         x = eval_data_col(data, mapping$x),
@@ -1804,19 +1774,23 @@ ggally_summarise_by <- function(
         weight = eval_data_col(data, mapping$weight) %||% 1,
         stringsAsFactors = FALSE
       ),
-      c('y'),
+      c("y"),
       plyr::here(summarize),
       label = text_fn(x, weight)
     )
     # keep colour if matching the discrete variable
-    if (mapping_string(mapping$colour) == mapping_string(mapping$y)) col <- "y"
-    else col <- NULL
+    if (mapping_string(mapping$colour) == mapping_string(mapping$y)) {
+      col <- as.name("y")
+    } else {
+      col <- NULL
+    }
 
     ggplot(res) +
-      aes_string(y = "y", x = "1", label = "label", colour = col) +
+      aes(y = !!as.name("y"), x = 1, label = !!as.name("label"), colour = !!col) +
       geom_text(...) +
-      xlab("") + ylab(mapping_string(mapping$y)) +
-      #theme_minimal() +
+      xlab("") +
+      ylab(mapping_string(mapping$y)) +
+      # theme_minimal() +
       theme(
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(),
@@ -1846,7 +1820,6 @@ ggally_summarise_by <- function(
       ) +
       theme(axis.text.x = element_text(size = 9))
   }
-
 }
 
 #' @rdname ggally_summarise_by
