@@ -1,12 +1,7 @@
-context("ggpairs")
 # This file takes too long
 testthat::skip_on_cran()
 
-data(tips, package = "reshape")
-
-expect_print <- function(p) {
-  testthat::expect_silent(print(p))
-}
+data(tips)
 
 facethistBindwidth1 <- list(combo = wrap("facethist", binwidth = 1))
 facethistBindwidth1Duo <- list(
@@ -20,35 +15,33 @@ test_that("structure", {
   }
 
   expect_obj <- function(x) {
-    expect_is(x$data, "data.frame")
-    expect_is(x$plots, "list")
-    expect_equivalent(length(x$plots), ncol(tips) ^ 2)
+    expect_s3_class(x$data, "data.frame")
+    expect_type(x$plots, "list")
+    expect_equal(length(x$plots), ncol(tips)^2)
     expect_null(x$title)
     expect_null(x$xlab)
     expect_null(x$ylab)
-    expect_is(x$xAxisLabels, "character")
-    expect_is(x$yAxisLabels, "character")
-    expect_is(x$showXAxisPlotLabels, "logical")
-    expect_is(x$showYAxisPlotLabels, "logical")
+    expect_type(x$xAxisLabels, "character")
+    expect_type(x$yAxisLabels, "character")
+    expect_type(x$showXAxisPlotLabels, "logical")
+    expect_type(x$showYAxisPlotLabels, "logical")
     expect_null(x$legend)
-    expect_is(x$byrow, "logical")
+    expect_type(x$byrow, "logical")
     expect_null(x$gg)
     expect_true("gg" %in% names(x))
   }
 
   expect_obj(ggduo(tips))
   expect_obj(ggpairs(tips))
-
-
 })
 
 test_that("columns", {
   expect_obj <- function(pm, columnsX, columnsY) {
-    expect_equivalent(length(pm$plots), length(columnsX) * length(columnsY))
-    expect_equivalent(pm$xAxisLabels, columnsX)
-    expect_equivalent(pm$yAxisLabels, columnsY)
-    expect_equivalent(pm$ncol, length(columnsX))
-    expect_equivalent(pm$nrow, length(columnsY))
+    expect_equal(length(pm$plots), length(columnsX) * length(columnsY))
+    expect_equal(pm$xAxisLabels, columnsX)
+    expect_equal(pm$yAxisLabels, columnsY)
+    expect_equal(pm$ncol, length(columnsX))
+    expect_equal(pm$nrow, length(columnsY))
   }
 
   columnsUsed <- c("total_bill", "tip", "sex")
@@ -59,13 +52,12 @@ test_that("columns", {
   columnsY <- c("smoker", "day", "time", "size")
   pm <- ggduo(tips, columnsX, columnsY)
   expect_obj(pm, columnsX, columnsY)
-
 })
 
 test_that("column labels", {
   expect_obj <- function(pm, columnLabelsX, columnLabelsY) {
-    expect_equivalent(pm$xAxisLabels, columnLabelsX)
-    expect_equivalent(pm$yAxisLabels, columnLabelsY)
+    expect_equal(pm$xAxisLabels, columnLabelsX)
+    expect_equal(pm$yAxisLabels, columnLabelsY)
   }
 
   columnTitles <- c("A", "B", "C")
@@ -80,7 +72,6 @@ test_that("column labels", {
   columnLabelsY <- c("Smoker !#@", "Day 678", "1", "NULL")
   pm <- ggduo(tips, 1:3, 4:7, columnLabelsX = columnLabelsX, columnLabelsY = columnLabelsY)
   expect_obj(pm, columnLabelsX, columnLabelsY)
-
 })
 
 test_that("character", {
@@ -106,116 +97,190 @@ test_that("upper/lower/diag = blank", {
   for (i in 1:3) {
     for (j in 1:3) {
       if (i < j) {
-        expect_true(  is_blank_plot(au[i, j]))
-        expect_false( is_blank_plot(ad[i, j]))
-        expect_false( is_blank_plot(al[i, j]))
+        expect_true(is_blank_plot(au[i, j]))
+        expect_false(is_blank_plot(ad[i, j]))
+        expect_false(is_blank_plot(al[i, j]))
       }
       if (i > j) {
-        expect_false( is_blank_plot(au[i, j]))
-        expect_false( is_blank_plot(ad[i, j]))
-        expect_true(  is_blank_plot(al[i, j]))
+        expect_false(is_blank_plot(au[i, j]))
+        expect_false(is_blank_plot(ad[i, j]))
+        expect_true(is_blank_plot(al[i, j]))
       }
       if (i == j) {
-        expect_false( is_blank_plot(au[i, j]))
-        expect_true(  is_blank_plot(ad[i, j]))
-        expect_false( is_blank_plot(al[i, j]))
+        expect_false(is_blank_plot(au[i, j]))
+        expect_true(is_blank_plot(ad[i, j]))
+        expect_false(is_blank_plot(al[i, j]))
       }
     }
   }
 
   a <- ggpairs(tips, columnsUsed)
-  a[1, 1] <- ggplot2::qplot(total_bill, data = tips)
+  a[1, 1] <- ggplot(tips, aes(total_bill)) +
+    geom_histogram()
   expect_false(is_blank_plot(a[1, 1]))
-
 })
 
 test_that("stops", {
+  expect_warning(
+    {
+      pm <- ggpairs(tips, axisLabels = "not_a_chosen", lower = facethistBindwidth1)
+    },
+    "'axisLabels' not in "
+  ) # nolint
+  expect_warning(
+    {
+      pm <- ggduo(tips, axisLabels = "not_a_chosen", types = facethistBindwidth1Duo)
+    },
+    "'axisLabels' not in "
+  ) # nolint
 
-  expect_warning({
-    pm <- ggpairs(tips, axisLabels = "not_a_chosen", lower = facethistBindwidth1)
-  }, "'axisLabels' not in ") # nolint
-  expect_warning({
-    pm <- ggduo(tips, axisLabels = "not_a_chosen", types = facethistBindwidth1Duo)
-  }, "'axisLabels' not in ") # nolint
+  expect_warning(
+    {
+      pm <- ggpairs(tips, color = "sex")
+    },
+    "Extra arguments: "
+  ) # nolint
 
-  expect_warning({
-    pm <- ggpairs(tips, color = "sex")
-  }, "Extra arguments: ") # nolint
+  expect_warning(
+    {
+      pm <- ggduo(tips, 2:3, 2:3, types = list(combo = "facetdensity"))
+    },
+    "Setting:\n\ttypes"
+  ) # nolint
 
-  expect_warning({
-    pm <- ggduo(tips, 2:3, 2:3, types = list(combo = "facetdensity"))
-  }, "Setting:\n\ttypes") # nolint
+  expect_error(
+    {
+      ggpairs(tips, columns = c("tip", "day", "not in tips"))
+    },
+    "Columns in 'columns' not found in data"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsX = c("tip", "day", "not in tips"), columnsY = "smoker")
+    },
+    "Columns in 'columnsX' not found in data"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsX = c("tip", "day", "smoker"), columnsY = "not in tips")
+    },
+    "Columns in 'columnsY' not found in data"
+  ) # nolint
 
-  expect_error({
-    ggpairs(tips, columns = c("tip", "day", "not in tips"))
-  }, "Columns in 'columns' not found in data") # nolint
-  expect_error({
-    ggduo(tips, columnsX = c("tip", "day", "not in tips"), columnsY = "smoker")
-  }, "Columns in 'columnsX' not found in data") # nolint
-  expect_error({
-    ggduo(tips, columnsX = c("tip", "day", "smoker"), columnsY = "not in tips")
-  }, "Columns in 'columnsY' not found in data") # nolint
+  expect_warning(
+    {
+      pm <- ggpairs(tips, legends = TRUE)
+    },
+    "'legends' will be deprecated"
+  ) # nolint
 
-  expect_warning({
-    pm <- ggpairs(tips, legends = TRUE)
-  }, "'legends' will be deprecated") # nolint
+  expect_error(
+    {
+      ggpairs(tips, params = c(size = 2))
+    },
+    "'params' is a deprecated"
+  ) # nolint
 
-  expect_error({
-    ggpairs(tips, params = c(size = 2))
-  }, "'params' is a deprecated") # nolint
+  expect_error(
+    {
+      ggpairs(tips, columns = 1:10)
+    },
+    "Make sure your numeric 'columns' values are less than or equal to"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsX = 1:10)
+    },
+    "Make sure your numeric 'columnsX' values are less than or equal to"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsY = 1:10)
+    },
+    "Make sure your numeric 'columnsY' values are less than or equal to"
+  ) # nolint
 
-  expect_error( {
-    ggpairs(tips, columns = 1:10)
-  }, "Make sure your numeric 'columns' values are less than or equal to") # nolint
-  expect_error( {
-    ggduo(tips, columnsX = 1:10)
-  }, "Make sure your numeric 'columnsX' values are less than or equal to") # nolint
-  expect_error( {
-    ggduo(tips, columnsY = 1:10)
-  }, "Make sure your numeric 'columnsY' values are less than or equal to") # nolint
+  expect_error(
+    {
+      ggpairs(tips, columns = -5:5)
+    },
+    "Make sure your numeric 'columns' values are positive"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsX = -5:5)
+    },
+    "Make sure your numeric 'columnsX' values are positive"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsY = -5:5)
+    },
+    "Make sure your numeric 'columnsY' values are positive"
+  ) # nolint
 
-  expect_error({
-    ggpairs(tips, columns = -5:5)
-  }, "Make sure your numeric 'columns' values are positive") # nolint
-  expect_error({
-    ggduo(tips, columnsX = -5:5)
-  }, "Make sure your numeric 'columnsX' values are positive") # nolint
-  expect_error({
-    ggduo(tips, columnsY = -5:5)
-  }, "Make sure your numeric 'columnsY' values are positive") # nolint
+  expect_error(
+    {
+      ggpairs(tips, columns = (2:10) / 2)
+    },
+    "Make sure your numeric 'columns' values are integers"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsX = (2:10) / 2)
+    },
+    "Make sure your numeric 'columnsX' values are integers"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsY = (2:10) / 2)
+    },
+    "Make sure your numeric 'columnsY' values are integers"
+  ) # nolint
 
-  expect_error({
-    ggpairs(tips, columns = (2:10) / 2)
-  }, "Make sure your numeric 'columns' values are integers") # nolint
-  expect_error({
-    ggduo(tips, columnsX = (2:10) / 2)
-  }, "Make sure your numeric 'columnsX' values are integers") # nolint
-  expect_error({
-    ggduo(tips, columnsY = (2:10) / 2)
-  }, "Make sure your numeric 'columnsY' values are integers") # nolint
+  expect_error(
+    {
+      ggpairs(tips, columns = 1:3, columnLabels = c("A", "B", "C", "Extra"))
+    },
+    "The length of the 'columnLabels' does not match the length of the 'columns'"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsX = 1:3, columnLabelsX = c("A", "B", "C", "Extra"))
+    },
+    "The length of the 'columnLabelsX' does not match the length of the 'columnsX'"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, columnsY = 1:3, columnLabelsY = c("A", "B", "C", "Extra"))
+    },
+    "The length of the 'columnLabelsY' does not match the length of the 'columnsY'"
+  ) # nolint
 
-  expect_error({
-    ggpairs(tips, columns = 1:3, columnLabels = c("A", "B", "C", "Extra"))
-  }, "The length of the 'columnLabels' does not match the length of the 'columns'") # nolint
-  expect_error({
-    ggduo(tips, columnsX = 1:3, columnLabelsX = c("A", "B", "C", "Extra"))
-  }, "The length of the 'columnLabelsX' does not match the length of the 'columnsX'") # nolint
-  expect_error({
-    ggduo(tips, columnsY = 1:3, columnLabelsY = c("A", "B", "C", "Extra"))
-  }, "The length of the 'columnLabelsY' does not match the length of the 'columnsY'") # nolint
-
-  expect_error({
-    ggpairs(tips, upper = c("not_a_list"))
-  }, "'upper' is not a list") # nolint
-  expect_error({
-    ggpairs(tips, diag = c("not_a_list"))
-  }, "'diag' is not a list") # nolint
-  expect_error({
-    ggpairs(tips, lower = c("not_a_list"))
-  }, "'lower' is not a list") # nolint
-  expect_error({
-    ggduo(tips, types = c("not_a_list"))
-  }, "'types' is not a list") # nolint
+  expect_error(
+    {
+      ggpairs(tips, upper = c("not_a_list"))
+    },
+    "'upper' is not a list"
+  ) # nolint
+  expect_error(
+    {
+      ggpairs(tips, diag = c("not_a_list"))
+    },
+    "'diag' is not a list"
+  ) # nolint
+  expect_error(
+    {
+      ggpairs(tips, lower = c("not_a_list"))
+    },
+    "'lower' is not a list"
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, types = c("not_a_list"))
+    },
+    "'types' is not a list"
+  ) # nolint
 
   # # couldn't get correct error message
   # #  variables: 'colour' have non standard format: 'total_bill + tip'.
@@ -227,25 +292,38 @@ test_that("stops", {
   # }, "variables\\: \"colour\" have non standard format") # nolint
 
   errorString <- "'aes_string' is a deprecated element"
-  expect_error({
-    ggpairs(tips, upper = list(aes_string = ggplot2::aes(color = day)))
-  }, errorString) # nolint
-  expect_error({
-    ggpairs(tips, lower = list(aes_string = ggplot2::aes(color = day)))
-  }, errorString) # nolint
-  expect_error({
-    ggpairs(tips, diag = list(aes_string = ggplot2::aes(color = day)))
-  }, errorString) # nolint
-  expect_error({
-    ggduo(tips, types = list(aes_string = ggplot2::aes(color = day)))
-  }, errorString) # nolint
+  expect_error(
+    {
+      ggpairs(tips, upper = list(aes_string = ggplot2::aes(color = day)))
+    },
+    errorString
+  ) # nolint
+  expect_error(
+    {
+      ggpairs(tips, lower = list(aes_string = ggplot2::aes(color = day)))
+    },
+    errorString
+  ) # nolint
+  expect_error(
+    {
+      ggpairs(tips, diag = list(aes_string = ggplot2::aes(color = day)))
+    },
+    errorString
+  ) # nolint
+  expect_error(
+    {
+      ggduo(tips, types = list(aes_string = ggplot2::aes(color = day)))
+    },
+    errorString
+  ) # nolint
 
 
   expect_diag_warn <- function(key, value) {
     warnString <- str_c("Changing diag\\$", key, " from '", value, "' to '", value, "Diag'")
     diagObj <- list()
     diagObj[[key]] <- value
-    expect_warning({
+    expect_warning(
+      {
         pm <- ggpairs(tips, diag = diagObj)
       },
       warnString
@@ -264,7 +342,6 @@ test_that("stops", {
   expect_diag_warn("continuous", "blank")
   expect_diag_warn("discrete", "bar")
   expect_diag_warn("discrete", "blank")
-
 })
 
 
@@ -294,19 +371,16 @@ test_that("blank types", {
         expect_true(is_blank_plot(pmUpper[i, j]))
         expect_false(is_blank_plot(pmDiag[i, j]))
         expect_false(is_blank_plot(pmLower[i, j]))
-
-      } else if ( i > j) {
+      } else if (i > j) {
         # lower
         expect_false(is_blank_plot(pmUpper[i, j]))
         expect_false(is_blank_plot(pmDiag[i, j]))
         expect_true(is_blank_plot(pmLower[i, j]))
-
       } else {
         # diag
         expect_false(is_blank_plot(pmUpper[i, j]))
         expect_true(is_blank_plot(pmDiag[i, j]))
         expect_false(is_blank_plot(pmLower[i, j]))
-
       }
     }
   }
@@ -322,7 +396,7 @@ test_that("blank types", {
 })
 
 test_that("axisLabels", {
-  expect_obj <- function(pm, axisLabel) {
+  expect_axis_labels <- function(pm, prefix, axisLabel) {
     expect_true(is.null(pm$showStrips))
     if (axisLabel == "show") {
       expect_true(pm$showXAxisPlotLabels)
@@ -346,7 +420,7 @@ test_that("axisLabels", {
       expect_false(is.null(pm$xAxisLabels))
       expect_false(is.null(pm$yAxisLabels))
     }
-    expect_print(pm)
+    vdiffr::expect_doppelganger(paste0("axisLabels-", prefix, "-", axisLabel), pm)
   }
 
   fn <- function(axisLabels) {
@@ -361,7 +435,7 @@ test_that("axisLabels", {
     pm
   }
   for (axisLabels in c("show", "internal", "none")) {
-    expect_obj(fn(axisLabels), axisLabels)
+    expect_axis_labels(fn(axisLabels), "ggpairs", axisLabels)
   }
 
   plots <- ggpairs(iris, 1:3)$plots
@@ -385,14 +459,12 @@ test_that("axisLabels", {
     a
   }
   for (axisLabels in c("show", "none")) {
-    expect_obj(fn(axisLabels), axisLabels)
+    expect_axis_labels(fn(axisLabels), "ggduo", axisLabels)
   }
-
 })
 
 
 test_that("strips and axis", {
-
   # axis should line up with left side strips
   pm <- ggpairs(
     tips, c(3, 1, 4),
@@ -400,7 +472,7 @@ test_that("strips and axis", {
     title = "Axis should line up even if strips are present",
     lower = list(combo = wrap("facethist", binwidth = 1))
   )
-  expect_print(pm)
+  vdiffr::expect_doppelganger("show-strips", pm)
   # default behavior. tested in other places
   # expect_silent({
   #   pm <- ggpairs(tips, c(3, 1, 4), showStrips = FALSE)
@@ -411,7 +483,7 @@ test_that("strips and axis", {
 
 test_that("dates", {
   startDt <- as.POSIXct("2000-01-01", tz = "UTC")
-  endDt   <- as.POSIXct("2000-04-01", tz = "UTC")
+  endDt <- as.POSIXct("2000-04-01", tz = "UTC")
 
   dts <- seq(startDt, endDt, 86400) # 86400 = as.numeric(ddays(1))
   x <- data.frame(
@@ -446,8 +518,6 @@ test_that("dates", {
   p <- a[1, 1]
   expect_true(inherits(p$layers[[1]]$geom, "GeomBar"))
   expect_equal(length(p$layers), 1)
-
-
 })
 
 
@@ -458,13 +528,15 @@ test_that("mapping", {
   pm <- ggpairs(tips, columns = 1:3)
   expect_equal(pm$xAxisLabels, names(tips)[1:3])
 
-  expect_error({
-    ggpairs(tips, columns = 1:3, mapping = 1:3)
-  }, "'mapping' should not be numeric") # nolint
+  expect_error(
+    {
+      ggpairs(tips, columns = 1:3, mapping = 1:3)
+    },
+    "'mapping' should not be numeric"
+  ) # nolint
 })
 
 test_that("user functions", {
-
   p0 <- ggally_points(tips, ggplot2::aes(x = total_bill, y = tip))
 
   pm1 <- ggpairs(tips, 1:2, lower = list(continuous = "points"))
@@ -494,7 +566,7 @@ test_that("NA data", {
   expect_is_na_plot <- function(p) {
     expect_true(identical(as.character(p$data$label), "NA"))
     expect_true(inherits(p$layers[[1]]$geom, "GeomText"))
-    expect_equivalent(length(p$layers), 1)
+    expect_equal(length(p$layers), 1)
   }
   expect_not_na_plot <- function(p) {
     expect_false(identical(as.character(p$data$label), "NA"))
@@ -512,8 +584,9 @@ test_that("NA data", {
         if (na_mat[i, j]) {
           expect_is_na_plot(pm[i, j])
         } else {
-          if (j == 3 & i < 3) {
-            expect_warning({
+          if (j == 3 && i < 3) {
+            expect_warning(
+              {
                 p <- pm[i, j]
               },
               "Removed 5 rows"
@@ -533,21 +606,15 @@ test_that("NA data", {
   na_mat[1:4, 4] <- TRUE
   na_mat[4, 1:4] <- TRUE
   test_pm(pm, na_mat)
-
 })
 
 test_that("strip-top and strip-right", {
-
-
-  data(tips, package = "reshape")
+  data(tips)
 
   double_strips <- function(data, mapping, ...) {
-    dt <- count(data, c(mapping_string(mapping$x), mapping_string(mapping$y)))
-    ggplot2::qplot(
-      xmin = 0.25, xmax = 0.75,
-      ymin = 1, ymax = freq,
-      data = dt, geom = "rect"
-    ) +
+    dt <- plyr::count(data, c(mapping_string(mapping$x), mapping_string(mapping$y)))
+    ggplot(dt, aes(xmin = 0.25, xmax = 0.75, ymin = 1, ymax = freq)) +
+      geom_rect() +
       ggplot2::facet_grid(paste0(mapping_string(mapping$y), " ~ ", mapping_string(mapping$x))) +
       ggplot2::scale_x_continuous(breaks = 0.5, labels = NULL)
   }
@@ -558,7 +625,7 @@ test_that("strip-top and strip-right", {
     upper = list(discrete = double_strips),
     progress = FALSE
   )
-  expect_print(pm)
+  vdiffr::expect_doppelganger("nested-strips-default", pm)
   pm <- ggpairs(
     tips, 3:6,
     lower = "blank", diag = "blank",
@@ -566,37 +633,35 @@ test_that("strip-top and strip-right", {
     showStrips = TRUE,
     progress = FALSE
   )
-  expect_print(pm)
-
+  vdiffr::expect_doppelganger("nested-strips-true", pm)
 })
 
 
 test_that("subtypes", {
-
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("Hmisc")
 
-# list of the different plot types to check
-# continuous
-#    points
-#    smooth
-#    smooth_loess
-#    density
-#    cor
-#   blank
+  # list of the different plot types to check
+  # continuous
+  #    points
+  #    smooth
+  #    smooth_loess
+  #    density
+  #    cor
+  #   blank
 
-# combo
-#   box
-#   dot plot
-#   facethist
-#   facetdensity
-#   denstrip
-#   blank
+  # combo
+  #   box
+  #   dot plot
+  #   facethist
+  #   facetdensity
+  #   denstrip
+  #   blank
 
-# discrete
-#   ratio
-#   facetbar
-#   blank
+  # discrete
+  #   ratio
+  #   facetbar
+  #   blank
 
   gn <- function(x) {
     fnName <- attr(x, "name")
@@ -609,11 +674,13 @@ test_that("subtypes", {
       axisLabels = "show",
       title = paste(
         "upper = c(cont = ", gn(types$continuous),
-          ", combo = ", gn(types$combo),
-          ", discrete = ", gn(types$discrete),
+        ", combo = ", gn(types$combo),
+        ", discrete = ", gn(types$discrete),
         "); diag = c(cont = ", gn(diag$continuous),
-          ", discrete = ", gn(diag$discrete),
-        ")", sep = ""),
+        ", discrete = ", gn(diag$discrete),
+        ")",
+        sep = ""
+      ),
       upper = types,
       lower = types,
       diag = diag,
@@ -635,9 +702,11 @@ test_that("subtypes", {
       axisLabels = "show",
       title = paste(
         "types = c(cont = ", gn(types$continuous),
-          ", combo = ", gn(types$comboHorizontal),
-          ", discrete = ", gn(types$discrete),
-        ")", sep = ""),
+        ", combo = ", gn(types$comboHorizontal),
+        ", discrete = ", gn(types$discrete),
+        ")",
+        sep = ""
+      ),
       types = types,
       progress = FALSE,
       ...
@@ -654,30 +723,46 @@ test_that("subtypes", {
   conSubs <- list(
     "autopoint",
     "density", "points", "smooth", "smooth_lm", "smooth_loess", "cor",
-    "blank")
+    "blank"
+  )
   comSubs <- list(
     "autopoint",
     "box", "dot", "box_no_facet", "dot_no_facet",
     wrap("facethist", binwidth = 1),
     "facetdensity",
     "facetdensitystrip",
-    "summarise_by",
+    # "summarise_by", # Issues with grid printing
     wrap("denstrip", binwidth = 1),
     "blank"
   )
   disSubs <- list(
     "autopoint", "colbar", "count",
     "cross", "crosstable", "facetbar",
-    "ratio", "rowbar", "table", "trends",
-    "blank")
+    "ratio", "rowbar",
+    "table",
+    # "trends", # Issues with grid printing
+    "blank"
+  )
 
   conDiagSubs <- c("autopointDiag", "densityDiag", wrap("barDiag", binwidth = 1), "blankDiag")
   disDiagSubs <- c("autopointDiag", "barDiag", "countDiag", "tableDiag", "blankDiag")
 
   # for (fn in list(ggpairs_fn1, ggpairs_fn2, ggduo_fn1, ggduo_fn2)) {
-  for (fn_num in 1:4) {
-    fn <- list(ggpairs_fn1, ggpairs_fn2, ggduo_fn1, ggduo_fn2)[[fn_num]]
-    for (i in 1:6) {
+  for (fn_info in list(
+    list(fn = ggpairs_fn1, title = "ggpairs"),
+    list(fn = ggpairs_fn2, title = "ggpairs_color"),
+    list(fn = ggduo_fn1, title = "ggduo"),
+    list(fn = ggduo_fn2, title = "ggduo_color")
+  )) {
+    fn <- fn_info$fn
+    fn_name <- fn_info$title
+    for (i in 1:max(c(
+      length(conSubs),
+      length(comSubs),
+      length(disSubs),
+      length(conDiagSubs),
+      length(disDiagSubs)
+    ))) {
       conSub <- if (i <= length(conSubs)) conSubs[[i]] else "blank"
       comSub <- if (i <= length(comSubs)) comSubs[[i]] else "blank"
       disSub <- if (i <= length(disSubs)) disSubs[[i]] else "blank"
@@ -712,17 +797,42 @@ test_that("subtypes", {
         )
       })
 
-      if (grepl("/Users/barret/", getwd(), fixed = TRUE)) {
-        # only if on personal machine, do viz test
-        expect_print(pm)
+      type_name <- function(x) {
+        if (is.function(x)) {
+          sub("ggally_", "", attr(x, "name"))
+        } else {
+          x
+        }
       }
+      type_names <- vapply(c(conSub, comSub, disSub, diagConSub, diagDisSub), type_name, character(1))
+      if (all(grepl("blank", type_names))) {
+        # vdiffr can't handle blank plots
+        next
+      }
+      pm_name <- paste0(type_names, collapse = "-")
+      pm_name <- paste0(fn_name, "-", pm_name)
+
+      tryCatch(
+        {
+          set.seed(123456) # keep jitter consistent
+          suppressWarnings({
+            built_pm <- ggmatrix_gtable(pm)
+          })
+          vdiffr::expect_doppelganger(pm_name, built_pm)
+        },
+        error = function(e) {
+          message("failed to create doppelganger: ", pm_name)
+          print(e)
+          barret <<- pm
+          expect_silent(print(c("failed to create doppelganger", pm_name)))
+        }
+      )
     }
   }
 
   expect_error({
     ggpairs(tips, 1:2, lower = "blank", diag = "blank", upper = list(continuous = "BAD_TYPE"))
   })
-
 })
 
 
@@ -739,7 +849,7 @@ test_that("subtypes", {
 #  # pm
 
 #  # Use sample of the diamonds data
-#  data(diamonds, package="ggplot2")
+#  data(diamonds, package = "ggplot2")
 #  diamonds.samp <- diamonds[sample(1:dim(diamonds)[1], 200), ]
 
 #  # Custom Example
@@ -762,19 +872,19 @@ test_that("subtypes", {
 #  # bad_plots
 
 #  # Only Variable Labels on the diagonal (no axis labels)
-#  pm <- ggpairs(tips[, 1:3], axisLabels="internal")
+#  pm <- ggpairs(tips[, 1:3], axisLabels = "internal")
 #  # pm
 #  # Only Variable Labels on the outside (no axis labels)
-#  pm <- ggpairs(tips[, 1:3], axisLabels="none")
+#  pm <- ggpairs(tips[, 1:3], axisLabels = "none")
 #  # pm
 
 #  # Custom Examples
 #  custom_car <- ggpairs(mtcars[, c("mpg", "wt", "cyl")], upper = "blank", title = "Custom Example")
 # #' # ggplot example taken from example(geom_text)
-# #'   plot <- ggplot2::ggplot(mtcars, ggplot2::aes(x=wt, y=mpg, label=rownames(mtcars)))
+# #'   plot <- ggplot2::ggplot(mtcars, ggplot2::aes(x = wt, y = mpg, label = rownames(mtcars)))
 # #'   plot <- plot +
-# #'     ggplot2::geom_text(ggplot2::aes(colour=factor(cyl)), size = 3) +
-# #'     ggplot2::scale_colour_discrete(l=40)
+# #'     ggplot2::geom_text(ggplot2::aes(colour = factor(cyl)), size = 3) +
+# #'     ggplot2::scale_colour_discrete(l = 40)
 # #' custom_car <- putPlot(custom_car, plot, 1, 2)
 # #' personal_plot <- ggally_text(
 # #'   "ggpairs allows you\nto put in your\nown plot.\nLike that one.\n <---"
